pub enum GcStatus {
Uninitialized,
NotInGC,
InConcurrentGC,
InPause,
PauseRequested,
Disabled(usize),
}Expand description
The status of MMTk’s GC subsystem. This doubles as the “is MMTk initialized” flag (via
GcStatus::Uninitialized) and as the state that tracks whether a GC is running and, if so,
what phase it is in. See GcStatusWord (the internal atomic encoding of this type) for how
this is stored atomically and which transitions between variants are legal.
Variants
Uninitialized
MMTk has not been initialized yet, i.e. initialize_collection() has not been called, so
there are no GC worker threads available to run a collection.
NotInGC
MMTk is initialized, and no GC is running, pending, or requested.
InConcurrentGC
A concurrent GC’s background work (e.g. concurrent marking) is running while mutators
continue to run normally. See ConcurrentPlan::concurrent_work_in_progress.
InPause
A stop-the-world pause is active: mutators are stopped and GC workers are doing pause work (e.g. tracing).
PauseRequested
A GC pause has been requested (by GcStatusWord::try_request_pause) but mutators have
not all stopped yet.
Disabled(usize)
Collection is currently disabled (e.g. by a mutator calling disable_collection()).
The usize payload is the non-zero nesting depth of disable calls:
each call to disable_collection() increments the depth, and each call to enable_collection()
decrements it. When the depth is about to reach zero, the status is transitioned to NoInGC.