PauseRequestOutcome

Enum PauseRequestOutcome 

pub(crate) enum PauseRequestOutcome {
    Uninitialized,
    AlreadyRequested,
    Requested,
}
Variants



Uninitialized

MMTk has not been initialized yet (initialize_collection() has not been called), so there are no GC worker threads to run a collection; no pause was (or could be) requested.



AlreadyRequested

A pause was already requested (by this call or a racing one); the caller does not need to do anything further.



Requested

This call transitioned the status to PauseRequested; the caller is responsible for requesting the pause (e.g. notifying the scheduler) exactly once.