pub(super) struct ConcurrentImmixGCWorkContext<VM>(PhantomData<VM>);Expand description
The GCWorkContext implementation for concurrent marking. Note that it overrides the
RootsWorkFactory.
Tuple Fields
0: PhantomData<VM>Trait Implementations
Sourceimpl<VM: VMBinding> GCWorkContext for ConcurrentImmixGCWorkContext<VM>
impl<VM: VMBinding> GCWorkContext for ConcurrentImmixGCWorkContext<VM>
type VM = VM
type PlanType = ConcurrentImmix<VM>
Sourcetype DefaultTrace = PlanTrace<<ConcurrentImmixGCWorkContext<VM> as GCWorkContext>::PlanType, TRACE_KIND_FAST>
type DefaultTrace = PlanTrace<<ConcurrentImmixGCWorkContext<VM> as GCWorkContext>::PlanType, TRACE_KIND_FAST>
The
Trace implementation to use for tracing edges that do not have special pinning
requirements. Concrete plans and spaces may choose to move or not to move the objects the
traced edges point to.Sourcetype PinningTrace = PlanTrace<<ConcurrentImmixGCWorkContext<VM> as GCWorkContext>::PlanType, TRACE_KIND_FAST>
type PinningTrace = PlanTrace<<ConcurrentImmixGCWorkContext<VM> as GCWorkContext>::PlanType, TRACE_KIND_FAST>
Sourcefn make_roots_work_factory(
mmtk: &'static MMTK<Self::VM>,
) -> impl RootsWorkFactory<<Self::VM as VMBinding>::VMSlot>
fn make_roots_work_factory( mmtk: &'static MMTK<Self::VM>, ) -> impl RootsWorkFactory<<Self::VM as VMBinding>::VMSlot>
Create an instance of
RootsWorkFactory for root scanning in the current GC. Read moreAuto Trait Implementations
impl<VM> Freeze for ConcurrentImmixGCWorkContext<VM>
impl<VM> RefUnwindSafe for ConcurrentImmixGCWorkContext<VM>where
VM: RefUnwindSafe,
impl<VM> Send for ConcurrentImmixGCWorkContext<VM>where
VM: Send,
impl<VM> Sync for ConcurrentImmixGCWorkContext<VM>where
VM: Sync,
impl<VM> Unpin for ConcurrentImmixGCWorkContext<VM>where
VM: Unpin,
impl<VM> UnwindSafe for ConcurrentImmixGCWorkContext<VM>where
VM: UnwindSafe,