struct SurvivalRatioPredictor {
alloc_vol: AtomicUsize,
copy_promote_vol: AtomicUsize,
prev_copy_promote_ratio: Atomic<f64>,
promote_vol: AtomicUsize,
prev_promote_ratio: Atomic<f64>,
}Expand description
Predicts how much of the young allocation in the coming cycle will survive.
Fields
alloc_vol: AtomicUsizeYoung allocation over the current cycle: the denominator of both ratios.
copy_promote_vol: AtomicUsizeVolume promoted by copying during the current cycle.
prev_copy_promote_ratio: Atomic<f64>Smoothed copy_promote_vol / alloc_vol over previous cycles.
promote_vol: AtomicUsizeVolume promoted by any means during the current cycle.
prev_promote_ratio: Atomic<f64>Smoothed promote_vol / alloc_vol over previous cycles.
Implementations
Sourceimpl SurvivalRatioPredictor
impl SurvivalRatioPredictor
pub fn set_alloc_size(&self, size: usize)
Sourcepub fn copy_promote_ratio(&self) -> f64
pub fn copy_promote_ratio(&self) -> f64
Fraction of young allocation that survived by being copied.
Sourcepub fn promote_ratio(&self) -> f64
pub fn promote_ratio(&self) -> f64
Fraction of young allocation that survived at all, copied or promoted in place.
pub fn update_ratios(&self)