ProcessNodes

Struct ProcessNodes 

pub struct ProcessNodes<T: Trace> {
    objects: Vec<ObjectReference>,
    bucket: WorkBucketStage,
    phantom_data: PhantomData<T>,
}
A work packet for scanning objects and optionally do node-enqueuing tracing during a stop-the-world tracing GC and the final mark pause of a concurrent GC.

It will scan each object. For objects that supports slot enqueuing, it will collect their slots and spawn ProcessSlots work packets to trace them. For objects that don’t support slot enqueuing, it will immediately trace their slots and spawn other ProcessNodes work packets to process their newly traced children. It is the VM’s responsibility to implement Scanning::scan_object_and_trace_edges to update the references to point to the new addresses in such a case.

Fields

objects: Vec<ObjectReference>bucket: WorkBucketStagephantom_data: PhantomData<T>

Implementations

Source

impl<T: Trace> ProcessNodes<T>

pub fn new(objects: Vec<ObjectReference>, bucket: WorkBucketStage) -> Self

fn try_enqueue_slots( &mut self, worker: &mut GCWorker<T::VM>, tls: VMWorkerThread, trace: &T, ) -> Vec<ObjectReference>

fn do_node_enqueuing_tracing( &mut self, worker: &mut GCWorker<T::VM>, tls: VMWorkerThread, trace: T, scan_later: Vec<ObjectReference>, )