ProcessSlots

Struct ProcessSlots 

pub struct ProcessSlots<T: Trace> {
    slots: Vec<<<T as Trace>::VM as VMBinding>::VMSlot>,
    bucket: WorkBucketStage,
}
A work packet for processing slots during a stop-the-world tracing GC and the final mark pause of a concurrent GC.

It will call trace_object on the value of each slot, and updates the slot if the object is moved or forwarded. It will spawn or immediately run the ProcessNodes work packet to scan newly traced objects.

Fields

slots: Vec<<<T as Trace>::VM as VMBinding>::VMSlot>bucket: WorkBucketStage

Implementations

Source

impl<T: Trace> ProcessSlots<T>

const SCAN_OBJECTS_IMMEDIATELY: bool = true

pub fn new( slots: Vec<<<T as Trace>::VM as VMBinding>::VMSlot>, bucket: WorkBucketStage, ) -> Self

fn process_slots( &mut self, worker: &mut GCWorker<T::VM>, trace: T, ) -> VectorQueue<ObjectReference>

fn flush( &mut self, worker: &mut GCWorker<T::VM>, queue: VectorQueue<ObjectReference>, )