pub(crate) struct DefaultRootsWorkFactory<VM: VMBinding, DT: Trace<VM = VM>, PT: Trace<VM = VM>> {
pub(crate) mmtk: &'static MMTK<VM>,
phantom: PhantomData<(DT, PT)>,
}Expand description
An implementation of RootsWorkFactory for stop-the-world tracing GC. It will create work
packets to find the transitive closure from roots, assuming mutators are stopped during the GC.
It creates the ProcessSlots work packet to handle non-pinning roots, and
ProcessPinningRoots to handle pinning roots (transitive or not). The work packets will be
added to the WorkBucketStage::TPinningClosure, WorkBucketStage::PinningRootsTrace and
WorkBucketStage::Closure buckets depending on the kinds of roots.
DT and PT are the Trace types for the default trace and pinning trace, respectively.
Fields
mmtk: &'static MMTK<VM>phantom: PhantomData<(DT, PT)>Implementations