ProcessPinningRoots

Struct ProcessPinningRoots 

pub(crate) struct ProcessPinningRoots<VM: VMBinding, R2OT: Trace<VM = VM>, O2OT: Trace<VM = VM>> {
    phantom: PhantomData<(VM, R2OT, O2OT)>,
    roots: Vec<ObjectReference>,
    bucket: WorkBucketStage,
}
This work packet processes pinning roots during stop-the-world tracing GC.

Note that by definition, a “root” is an edge from outside the object graph to an object. This work packet represents each edge as the ObjectReference of the object the edge points to (i.e. the referent). Because pinning roots by definition cannot be updated, we don’t need to represent the edges as Slot.

The roots member holds a list of ObjectReference to objects directly pointed by roots. These objects will be traced using R2OT (Root-to-Object Trace).

After that, it will create work packets for tracing their children. Those work packets (and the work packets further created by them) will use O2OT (Object-to-Object Trace) as their Trace implementations.

Because roots are pinning roots, R2OT must be a Trace that never moves any object.

The choice of O2OT determines whether the roots are transitively pinning or not.

  • If O2OT is set to a Trace that never moves objects, no descendents of roots will be moved in this GC. That implements transitive pinning roots.
  • If O2OT may move objects, then this ProcessRootsNode<VM, R2OT, O2OT> work packet will only pin the objects in roots (because R2OT must not move objects anyway), but not their descendents.

Fields

phantom: PhantomData<(VM, R2OT, O2OT)>roots: Vec<ObjectReference>bucket: WorkBucketStage

Implementations

Source

impl<VM: VMBinding, R2OT: Trace<VM = VM>, O2OT: Trace<VM = VM>> ProcessPinningRoots<VM, R2OT, O2OT>

pub fn new(nodes: Vec<ObjectReference>, bucket: WorkBucketStage) -> Self