pub(crate) struct DefaultObjectTracerContext<T: Trace> {
stage: WorkBucketStage,
phantom_data: PhantomData<T>,
}Expand description
This implementation of ObjectTracerContext creates the DefaultObjectTracer to expand the
transitive closure during a stop-the-world tracing GC or the final mark pause of a concurrent
GC. It is used during object scanning as well as weak reference processing.
Fields
stage: WorkBucketStagephantom_data: PhantomData<T>Implementations
Sourceimpl<T: Trace> DefaultObjectTracerContext<T>
impl<T: Trace> DefaultObjectTracerContext<T>
pub fn new(stage: WorkBucketStage) -> Self