SFTTrace

Struct SFTTrace 

pub struct SFTTrace<VM: VMBinding> {
    phantom_data: PhantomData<VM>,
}
A Trace implementation that dispatches the trace_object method through crate::policy::sft::SFT::sft_trace_object using the Space Function Table (SFT).

Because SFT methods cannot be general, SFTTrace cannot be used for plans that needs multiple traces. It is sufficient for simple plans such as MarkSweep and SemiSpace.

Fields

phantom_data: PhantomData<VM>