pub struct LargeObjectSpace<VM: VMBinding> {
common: CommonSpace<VM>,
pr: FreeListPageResource<VM>,
mark_state: u8,
in_nursery_gc: bool,
treadmill: TreadMill,
clear_log_bit_on_sweep: bool,
pub num_pages_released_lazy: AtomicUsize,
pub rc_enabled: bool,
pub(crate) rc: RefCountHelper<VM>,
pub is_end_of_satb_or_full_gc: bool,
pub(crate) bump_page_reuse_count: AtomicBool,
}Expand description
This type implements a policy for large objects. Each instance corresponds to one Treadmill space.
Fields
common: CommonSpace<VM>pr: FreeListPageResource<VM>mark_state: u8in_nursery_gc: booltreadmill: TreadMillclear_log_bit_on_sweep: boolnum_pages_released_lazy: AtomicUsizerc_enabled: boolrc: RefCountHelper<VM>is_end_of_satb_or_full_gc: boolbump_page_reuse_count: AtomicBoolWhether newly allocated LOS objects should bump LOS_PAGE_REUSE_COUNT on their pages, so
remembered-set entries recorded against a page’s previous occupant are invalidated. Only
needed while concurrent marking can be validating a remembered set; set/cleared by the
owning plan (currently only LXR) as concurrent marking starts/ends.
Implementations
Sourceimpl<VM: VMBinding> LargeObjectSpace<VM>
impl<VM: VMBinding> LargeObjectSpace<VM>
pub fn new( args: PlanCreateSpaceArgs<'_, VM>, protect_memory_on_release: bool, clear_log_bit_on_sweep: bool, ) -> Self
fn release_object(&self, object: ObjectReference) -> usize
pub fn release_rc_nursery_objects(&self)
pub fn prepare(&mut self, full_heap: bool)
pub fn release(&mut self, full_heap: bool)
pub fn trace_object<Q: ObjectQueue>( &self, queue: &mut Q, object: ObjectReference, ) -> ObjectReference
fn sweep_large_pages(&mut self, sweep_nursery: bool)
Sourcepub(crate) fn enumerate_to_space_objects(
&self,
enumerator: &mut dyn ObjectEnumerator,
)
pub(crate) fn enumerate_to_space_objects( &self, enumerator: &mut dyn ObjectEnumerator, )
Enumerate objects in the to-space. It is a workaround for OVC which currently needs to enumerate reachable objects for during reference forwarding.
Sourcepub fn allocate_pages(
&self,
tls: VMThread,
pages: usize,
alloc_options: AllocationOptions,
) -> Address
pub fn allocate_pages( &self, tls: VMThread, pages: usize, alloc_options: AllocationOptions, ) -> Address
Allocate an object
pub fn attempt_mark(&self, object: ObjectReference) -> bool
pub fn rc_free(&self, o: ObjectReference)
Sourcefn test_and_mark(&self, object: ObjectReference, value: u8) -> bool
fn test_and_mark(&self, object: ObjectReference, value: u8) -> bool
Test if the object’s mark bit is the same as the given value. If it is not the same, the method will attemp to mark the object and clear its nursery bit. If the attempt succeeds, the method will return true, meaning the object is marked by this invocation. Otherwise, it returns false.
fn test_mark_bit(&self, object: ObjectReference, value: u8) -> bool
Sourcefn is_in_nursery(&self, object: ObjectReference) -> bool
fn is_in_nursery(&self, object: ObjectReference) -> bool
Check if a given object is in nursery
pub fn sweep_rc_mature_objects_after_satb( &self, is_live: &impl Fn(ObjectReference) -> bool, )
pub fn is_marked(&self, object: ObjectReference) -> bool