pub(crate) struct OVCRegion(Address);Expand description
A OVCRegion is the granularity at which super::OVCSpace
compacts the heap. Objects are allocated inside one region, and are only ever
moved within that region.
Tuple Fields
0: AddressTrait Implementations
Sourceimpl PartialOrd for OVCRegion
impl PartialOrd for OVCRegion
Sourceimpl Region for OVCRegion
impl Region for OVCRegion
Sourcefn from_aligned_address(address: Address) -> Self
fn from_aligned_address(address: Address) -> Self
Create a region from an address that is aligned to the region boundary. The method should panic if the address
is not properly aligned to the region. For performance, this method should always be inlined.
Sourcefn start(&self) -> Address
fn start(&self) -> Address
Return the start address of the region. For performance, this method should always be inlined.
Sourcefn from_unaligned_address(address: Address) -> Self
fn from_unaligned_address(address: Address) -> Self
Create a region from an arbitrary address.
Sourcefn is_aligned(address: Address) -> bool
fn is_aligned(address: Address) -> bool
Check if an address is aligned to the region.
Sourcefn end(&self) -> Address
fn end(&self) -> Address
Return the end address of the region. Note that the end address is not in the region.
Sourcefn containing(object: ObjectReference) -> Self
fn containing(object: ObjectReference) -> Self
Return the region that contains the object.
Sourcefn includes_address(&self, addr: Address) -> bool
fn includes_address(&self, addr: Address) -> bool
Check if the given address is in the region.
impl Copy for OVCRegion
impl StructuralPartialEq for OVCRegion