#[repr(u8)]pub enum RootKind {
Strong = 0,
YoungCodeCacheRoots = 1,
Weak = 2,
}Expand description
The kind of a set of roots. Used by LXR to decide how roots should be processed (e.g. reference counting and remembered-set recording).
Variants
Strong = 0
Ordinary strong roots, e.g. mutator stacks and globals. These are reference-counted and marked like any other strong reference.
YoungCodeCacheRoots = 1
Roots held by recently JIT-compiled (“young”) code-cache entries. These are recorded into the remembered set (instead of being reference-counted) so the code cache can be re-scanned on a later GC.
Weak = 2
Roots that hold weak references. These must not keep their referents alive and are not reference-counted.
Implementations
Sourceimpl RootKind
impl RootKind
Sourcepub fn should_record_remset(&self) -> bool
pub fn should_record_remset(&self) -> bool
Whether roots of this kind should be recorded into the remembered set rather than being processed like normal roots.
Sourcepub fn should_skip_mark_and_decs(&self) -> bool
pub fn should_skip_mark_and_decs(&self) -> bool
Whether roots of this kind should skip marking and reference-count decrements.
Sourcepub fn should_skip_decs(&self) -> bool
pub fn should_skip_decs(&self) -> bool
Whether roots of this kind should skip reference-count decrements.