pub struct GCWorkerShared<VM: VMBinding> {
stat: AtomicRefCell<WorkerLocalStat<VM>>,
pub live_bytes_per_space: AtomicRefCell<[usize; 16]>,
pub designated_work: ArrayQueue<Box<dyn GCWork<VM>>>,
pub stealer: Option<Stealer<Box<dyn GCWork<VM>>>>,
}Expand description
The struct has one instance per worker, but is shared between workers via the scheduler instance. This structure is used for communication between workers, e.g. adding designated work packets, stealing work packets from other workers, and collecting per-worker statistics.
Fields
stat: AtomicRefCell<WorkerLocalStat<VM>>Worker-local statistics data.
live_bytes_per_space: AtomicRefCell<[usize; 16]>Accumulated bytes for live objects in this GC. When each worker scans objects, we increase the live bytes. We get this value from each worker at the end of a GC, and reset this counter. The live bytes are stored in an array. The index is the index from the space descriptor.
designated_work: ArrayQueue<Box<dyn GCWork<VM>>>A queue of GCWork that can only be processed by the owned thread.
stealer: Option<Stealer<Box<dyn GCWork<VM>>>>Handle for stealing packets from the current worker
Implementations
Sourcepub fn new(stealer: Option<Stealer<Box<dyn GCWork<VM>>>>) -> Self
pub fn new(stealer: Option<Stealer<Box<dyn GCWork<VM>>>>) -> Self
Create a new GCWorkerShared instance, optionally with a stealer handle that other
workers can use to steal work packets from this worker’s local queue.
pub(crate) fn increase_live_bytes( live_bytes_per_space: &mut [usize; 16], object: ObjectReference, )
Sourcepub fn borrow_stat(&self) -> AtomicRef<'_, WorkerLocalStat<VM>>
pub fn borrow_stat(&self) -> AtomicRef<'_, WorkerLocalStat<VM>>
Immutably borrow this worker’s local statistics.
Sourcepub fn borrow_stat_mut(&self) -> AtomicRefMut<'_, WorkerLocalStat<VM>>
pub fn borrow_stat_mut(&self) -> AtomicRefMut<'_, WorkerLocalStat<VM>>
Mutably borrow this worker’s local statistics.