struct WorkerParker {
worker_count: usize,
parked_workers: AtomicUsize,
}Expand description
This struct counts the number of workers parked and identifies the last parked worker.
Fields
worker_count: usizeThe total number of workers.
parked_workers: AtomicUsizeNumber of parked workers. The counter can be read without a lock, but can only be mutated while holding the monitor’s lock.
Implementations
Sourceimpl WorkerParker
impl WorkerParker
fn new(worker_count: usize) -> Self
Sourcefn parked_workers(&self) -> usize
fn parked_workers(&self) -> usize
Number of workers currently inside park_and_wait.
Deliberately readable without the monitor’s lock.
Sourcefn inc_parked_workers(&self, _sync: &WorkerMonitorSync) -> bool
fn inc_parked_workers(&self, _sync: &WorkerMonitorSync) -> bool
Increase the packed-workers counter. Called before a worker is parked. The caller must hold the monitor’s lock.
Return true if all the workers are parked.
Sourcefn dec_parked_workers(&self, _sync: &WorkerMonitorSync)
fn dec_parked_workers(&self, _sync: &WorkerMonitorSync)
Decrease the packed-workers counter. Called after a worker is resumed from the parked state. The caller must hold the monitor’s lock.