pub fn global_side_metadata_vm_base_address() -> AddressExpand description
The base address for the global side metadata space available to VM bindings, to be used for the per-object metadata. VM bindings must use this to avoid overlap with core internal global side metadata.