side_metadata_offset_after

Function side_metadata_offset_after 

pub const fn side_metadata_offset_after(spec: &SideMetadataSpec) -> usize
Calculate the offset of the next side metadata spec after the given spec. This is used to calculate the offset field in crate::util::metadata::side_metadata::SideMetadataSpec.