data_to_meta_size_round_up

Function data_to_meta_size_round_up 

pub(super) const fn data_to_meta_size_round_up(
    metadata_spec: &SideMetadataSpec,
    data_size: usize,
) -> usize
Calculate the amount of metadata needed for the give amount of data memory, round up to nearest integer. data_size can be in any unit, e.g. bits, bytes, pages, blocks, chunks, etc., and the result has the same unit.