pub(super) fn initialize_side_metadata_base(
specified_base: Address,
huge_page_support: HugePageSupport,
)Expand description
Initialize the side metadata base address by reserving address space with quarantine mmap.
pub(super) fn initialize_side_metadata_base(
specified_base: Address,
huge_page_support: HugePageSupport,
)Initialize the side metadata base address by reserving address space with quarantine mmap.