pub struct MmapStrategy {
pub huge_page: HugePageSupport,
pub prot: MmapProtection,
pub replace: bool,
pub reserve: bool,
}Expand description
Strategy for performing mmap
Fields
huge_page: HugePageSupportWhether we should use huge page for this mmapping. Fallback: for platforms that do not support huge pages, this option can be ignored.
prot: MmapProtectionThe protection flags for mmap.
replace: boolWhether this mmap allows replacing existing mappings. Fallback: for platforms that cannot replace existing mappings, or always replace existing mappings, this option can be ignored.
reserve: boolWhether this mmap allows reserve/commit physical memory. This has to be implemented properly for a platform. Otherwise, we will see huge unrealistic memory consumption.
Implementations
Sourceimpl MmapStrategy
impl MmapStrategy
Sourcepub const INTERNAL_MEMORY: Self
pub const INTERNAL_MEMORY: Self
The strategy for MMTk’s own internal memory
Sourcepub fn new(
huge_page: HugePageSupport,
prot: MmapProtection,
replace: bool,
reserve: bool,
) -> Self
pub fn new( huge_page: HugePageSupport, prot: MmapProtection, replace: bool, reserve: bool, ) -> Self
Create a new strategy
Sourcepub fn huge_page(self, huge_page: HugePageSupport) -> Self
pub fn huge_page(self, huge_page: HugePageSupport) -> Self
Set huge page option.
Sourcepub fn transparent_hugepages(self, enable: bool) -> Self
pub fn transparent_hugepages(self, enable: bool) -> Self
Set huge page option by a boolean flag.
Sourcepub fn prot(self, prot: MmapProtection) -> Self
pub fn prot(self, prot: MmapProtection) -> Self
Set protection option.
Sourceimpl MmapStrategy
impl MmapStrategy
Sourcepub fn get_posix_mmap_flags(&self) -> i32
pub fn get_posix_mmap_flags(&self) -> i32
get the flags for POSIX mmap.