pub struct SFTTrace<VM: VMBinding> {
phantom_data: PhantomData<VM>,
}Expand description
A Trace implementation that dispatches the trace_object method through
crate::policy::sft::SFT::sft_trace_object using the Space Function Table (SFT).
Because SFT methods cannot be general, SFTTrace cannot be used for plans that needs multiple
traces. It is sufficient for simple plans such as MarkSweep and SemiSpace.
Fields
phantom_data: PhantomData<VM>Trait Implementations
Sourceimpl<VM: VMBinding> Trace for SFTTrace<VM>
impl<VM: VMBinding> Trace for SFTTrace<VM>
Sourcefn trace_object<Q: ObjectQueue>(
&self,
worker: &mut GCWorker<VM>,
object: ObjectReference,
queue: &mut Q,
) -> ObjectReference
fn trace_object<Q: ObjectQueue>( &self, worker: &mut GCWorker<VM>, object: ObjectReference, queue: &mut Q, ) -> ObjectReference
Sourcefn post_scan_object(&self, _object: ObjectReference)
fn post_scan_object(&self, _object: ObjectReference)
The post-scan hook to be call after scanning
object. Read moreSourcefn may_move_objects() -> bool
fn may_move_objects() -> bool
Return
true if Self::trace_object may move any object. If any space of the current
plan may move objects during this trace, this method should return true. Read moreAuto Trait Implementations
impl<VM> Freeze for SFTTrace<VM>
impl<VM> RefUnwindSafe for SFTTrace<VM>where
VM: RefUnwindSafe,
impl<VM> Send for SFTTrace<VM>
impl<VM> Sync for SFTTrace<VM>
impl<VM> Unpin for SFTTrace<VM>where
VM: Unpin,
impl<VM> UnwindSafe for SFTTrace<VM>where
VM: UnwindSafe,