pub const fn side_metadata_offset_after(spec: &SideMetadataSpec) -> usizeExpand description
Calculate the offset of the next side metadata spec after the given spec.
This is used to calculate the offset field in crate::util::metadata::side_metadata::SideMetadataSpec.