pub fn visit_children<VM, const MAY_MOVE_OBJECTS: bool>(
tls: VMWorkerThread,
object: ObjectReference,
object_tracer: &mut impl ObjectTracer,
)where
VM: VMBinding,Expand description
Visit and potentially update the children of object using Scanning::scan_object or
Scanning::scan_object_and_trace_edges depending on the result of
Scanning::support_slot_enqueuing.
This function is mainly used as a convenient function for simple node-enqueuing tracing loops.